@@ -77,7 +77,10 @@ SongFilter::Item::Item(unsigned _tag, time_t _time)
 bool
 SongFilter::Item::StringMatch(const char *s) const
 {
+#if !CLANG_CHECK_VERSION(3,6)
+	/* disabled on clang due to -Wtautological-pointer-compare */
 	assert(s != nullptr);
+#endif
 
 	if (fold_case) {
 		const std::string folded = IcuCaseFold(s);
