@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 The Music Player Daemon Project
+ * Copyright (C) 2003-2014 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,10 +19,11 @@
 
 #include "config.h"
 #include "SongSave.hxx"
-#include "Song.hxx"
+#include "db/plugins/simple/Song.hxx"
+#include "DetachedSong.hxx"
 #include "TagSave.hxx"
-#include "Directory.hxx"
-#include "TextFile.hxx"
+#include "fs/io/TextFile.hxx"
+#include "fs/io/BufferedOutputStream.hxx"
 #include "tag/Tag.hxx"
 #include "tag/TagBuilder.hxx"
 #include "util/StringUtil.hxx"
@@ -37,41 +38,55 @@
 
 static constexpr Domain song_save_domain("song_save");
 
-void
-song_save(FILE *fp, const Song &song)
+static void
+range_save(BufferedOutputStream &os, unsigned start_ms, unsigned end_ms)
 {
-	fprintf(fp, SONG_BEGIN "%s\n", song.uri);
-
-	if (song.end_ms > 0)
-		fprintf(fp, "Range: %u-%u\n", song.start_ms, song.end_ms);
-	else if (song.start_ms > 0)
-		fprintf(fp, "Range: %u-\n", song.start_ms);
-
-	if (song.tag != nullptr)
-		tag_save(fp, *song.tag);
-
-	fprintf(fp, SONG_MTIME ": %li\n", (long)song.mtime);
-	fprintf(fp, SONG_END "\n");
+	if (end_ms > 0)
+		os.Format("Range: %u-%u\n", start_ms, end_ms);
+	else if (start_ms > 0)
+		os.Format("Range: %u-\n", start_ms);
 }
 
-Song *
-song_load(TextFile &file, Directory *parent, const char *uri,
+void
+song_save(BufferedOutputStream &os, const Song &song)
+{
+	os.Format(SONG_BEGIN "%s\n", song.uri);
+
+	range_save(os, song.start_time.ToMS(), song.end_time.ToMS());
+
+	tag_save(os, song.tag);
+
+	os.Format(SONG_MTIME ": %li\n", (long)song.mtime);
+	os.Format(SONG_END "\n");
+}
+
+void
+song_save(BufferedOutputStream &os, const DetachedSong &song)
+{
+	os.Format(SONG_BEGIN "%s\n", song.GetURI());
+
+	range_save(os, song.GetStartTime().ToMS(), song.GetEndTime().ToMS());
+
+	tag_save(os, song.GetTag());
+
+	os.Format(SONG_MTIME ": %li\n", (long)song.GetLastModified());
+	os.Format(SONG_END "\n");
+}
+
+DetachedSong *
+song_load(TextFile &file, const char *uri,
 	  Error &error)
 {
-	Song *song = parent != nullptr
-		? Song::NewFile(uri, parent)
-		: Song::NewRemote(uri);
-	char *line, *colon;
-	TagType type;
-	const char *value;
+	DetachedSong *song = new DetachedSong(uri);
 
 	TagBuilder tag;
 
+	char *line;
 	while ((line = file.ReadLine()) != nullptr &&
 	       strcmp(line, SONG_END) != 0) {
-		colon = strchr(line, ':');
+		char *colon = strchr(line, ':');
 		if (colon == nullptr || colon == line) {
-			song->Free();
+			delete song;
 
 			error.Format(song_save_domain,
 				     "unknown line in db: %s", line);
@@ -79,24 +94,29 @@ song_load(TextFile &file, Directory *parent, const char *uri,
 		}
 
 		*colon++ = 0;
-		value = strchug_fast(colon);
+		const char *value = StripLeft(colon);
 
+		TagType type;
 		if ((type = tag_name_parse(line)) != TAG_NUM_OF_ITEM_TYPES) {
 			tag.AddItem(type, value);
 		} else if (strcmp(line, "Time") == 0) {
-			tag.SetTime(atoi(value));
+			tag.SetDuration(SignedSongTime::FromS(atof(value)));
 		} else if (strcmp(line, "Playlist") == 0) {
 			tag.SetHasPlaylist(strcmp(value, "yes") == 0);
 		} else if (strcmp(line, SONG_MTIME) == 0) {
-			song->mtime = atoi(value);
+			song->SetLastModified(atoi(value));
 		} else if (strcmp(line, "Range") == 0) {
 			char *endptr;
 
-			song->start_ms = strtoul(value, &endptr, 10);
-			if (*endptr == '-')
-				song->end_ms = strtoul(endptr + 1, nullptr, 10);
+			unsigned start_ms = strtoul(value, &endptr, 10);
+			unsigned end_ms = *endptr == '-'
+				? strtoul(endptr + 1, nullptr, 10)
+				: 0;
+
+			song->SetStartTime(SongTime::FromMS(start_ms));
+			song->SetEndTime(SongTime::FromMS(end_ms));
 		} else {
-			song->Free();
+			delete song;
 
 			error.Format(song_save_domain,
 				     "unknown line in db: %s", line);
@@ -104,8 +124,6 @@ song_load(TextFile &file, Directory *parent, const char *uri,
 		}
 	}
 
-	if (tag.IsDefined())
-		song->tag = tag.Commit();
-
+	song->SetTag(tag.Commit());
 	return song;
 }
