@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 The Music Player Daemon Project
+ * Copyright (C) 2003-2014 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 
 #include "config.h"
 #include "TimePrint.hxx"
-#include "Client.hxx"
+#include "client/Client.hxx"
 
 void
 time_print(Client &client, const char *name, time_t t)
