@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 The Music Player Daemon Project
+ * Copyright (C) 2003-2014 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,6 +22,9 @@
 #include "system/SocketError.hxx"
 #include "util/Error.hxx"
 #include "util/Domain.hxx"
+#include "Compiler.h"
+
+#include <algorithm>
 
 BufferedSocket::ssize_t
 BufferedSocket::DirectRead(void *data, size_t length)
