@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 The Music Player Daemon Project
+ * Copyright (C) 2003-2014 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 #include "config.h"
 #include "FullyBufferedSocket.hxx"
 #include "system/SocketError.hxx"
-#include "util/fifo_buffer.h"
 #include "util/Error.hxx"
 #include "util/Domain.hxx"
+#include "Compiler.h"
 
 #include <assert.h>
 #include <stdint.h>
@@ -59,15 +59,14 @@ FullyBufferedSocket::Flush()
 {
 	assert(IsDefined());
 
-	size_t length;
-	const void *data = output.Read(&length);
-	if (data == nullptr) {
+	const auto data = output.Read();
+	if (data.IsEmpty()) {
 		IdleMonitor::Cancel();
 		CancelWrite();
 		return true;
 	}
 
-	auto nbytes = DirectWrite(data, length);
+	auto nbytes = DirectWrite(data.data, data.size);
 	if (gcc_unlikely(nbytes <= 0))
 		return nbytes == 0;
 
