@@ -26,7 +26,6 @@
 #include "AudioFormat.hxx"
 #include "util/ConstBuffer.hxx"
 #include "util/Error.hxx"
-#include "util/Domain.hxx"
 
 #include <assert.h>
 #include <string.h>
@@ -50,8 +49,6 @@ public:
 				    Error &error) override;
 };
 
-static constexpr Domain volume_domain("pcm_volume");
-
 static Filter *
 volume_filter_init(gcc_unused const config_param &param,
 		   gcc_unused Error &error)
