@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 The Music Player Daemon Project
+ * Copyright (C) 2003-2014 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,25 +26,3 @@ Path::ToUTF8() const
 {
 	return ::PathToUTF8(c_str());
 }
-
-const char *
-Path::RelativeFS(const char *other_fs) const
-{
-	const size_t l = length();
-	if (memcmp(data(), other_fs, l) != 0)
-		return nullptr;
-
-	other_fs += l;
-	if (*other_fs != 0) {
-		if (!PathTraits::IsSeparatorFS(*other_fs))
-			/* mismatch */
-			return nullptr;
-
-		/* skip remaining path separators */
-		do {
-			++other_fs;
-		} while (PathTraits::IsSeparatorFS(*other_fs));
-	}
-
-	return other_fs;
-}
