@@ -54,10 +54,6 @@
 #include "plugins/CdioParanoiaInputPlugin.hxx"
 #endif
 
-#ifdef ENABLE_DESPOTIFY
-#include "plugins/DespotifyInputPlugin.hxx"
-#endif
-
 const InputPlugin *const input_plugins[] = {
 	&input_plugin_file,
 #ifdef HAVE_ALSA
@@ -83,9 +79,6 @@ const InputPlugin *const input_plugins[] = {
 #endif
 #ifdef ENABLE_CDIO_PARANOIA
 	&input_plugin_cdio_paranoia,
-#endif
-#ifdef ENABLE_DESPOTIFY
-	&input_plugin_despotify,
 #endif
 	nullptr
 };
