@@ -58,9 +58,6 @@ static const char *remoteUrlPrefixes[] = {
 #ifdef ENABLE_CDIO_PARANOIA
 	"cdda://",
 #endif
-#ifdef ENABLE_DESPOTIFY
-	"spt://",
-#endif
 #ifdef HAVE_ALSA
 	"alsa://",
 #endif
