@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2011 The Music Player Daemon Project
+ * Copyright (C) 2003-2014 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,48 +19,46 @@
 
 #include "config.h"
 #include "TagSave.hxx"
-#include "Song.hxx"
-#include "SongEnumerator.hxx"
-#include "Directory.hxx"
-#include "InputStream.hxx"
-#include "ConfigGlobal.hxx"
-#include "DecoderList.hxx"
-#include "InputInit.hxx"
-#include "IOThread.hxx"
-#include "PlaylistRegistry.hxx"
-#include "PlaylistPlugin.hxx"
+#include "DetachedSong.hxx"
+#include "playlist/SongEnumerator.hxx"
+#include "input/InputStream.hxx"
+#include "config/ConfigGlobal.hxx"
+#include "decoder/DecoderList.hxx"
+#include "input/Init.hxx"
+#include "ScopeIOThread.hxx"
+#include "playlist/PlaylistRegistry.hxx"
+#include "playlist/PlaylistPlugin.hxx"
 #include "fs/Path.hxx"
+#include "fs/io/BufferedOutputStream.hxx"
+#include "fs/io/StdioOutputStream.hxx"
 #include "util/Error.hxx"
 #include "thread/Cond.hxx"
 #include "Log.hxx"
 
+#ifdef HAVE_GLIB
 #include <glib.h>
+#endif
 
 #include <unistd.h>
 #include <stdlib.h>
 
-Directory::Directory() {}
-Directory::~Directory() {}
-
 static void
-my_log_func(const gchar *log_domain, gcc_unused GLogLevelFlags log_level,
-	    const gchar *message, gcc_unused gpointer user_data)
+tag_save(FILE *file, const Tag &tag)
 {
-	if (log_domain != NULL)
-		g_printerr("%s: %s\n", log_domain, message);
-	else
-		g_printerr("%s\n", message);
+	StdioOutputStream sos(file);
+	BufferedOutputStream bos(sos);
+	tag_save(bos, tag);
+	bos.Flush();
 }
 
 int main(int argc, char **argv)
 {
 	const char *uri;
 	InputStream *is = NULL;
-	Song *song;
 
 	if (argc != 3) {
-		g_printerr("Usage: dump_playlist CONFIG URI\n");
-		return 1;
+		fprintf(stderr, "Usage: dump_playlist CONFIG URI\n");
+		return EXIT_FAILURE;
 	}
 
 	const Path config_path = Path::FromFS(argv[1]);
@@ -68,11 +66,11 @@ int main(int argc, char **argv)
 
 	/* initialize GLib */
 
+#ifdef HAVE_GLIB
 #if !GLIB_CHECK_VERSION(2,32,0)
 	g_thread_init(NULL);
 #endif
-
-	g_log_set_default_handler(my_log_func, NULL);
+#endif
 
 	/* initialize MPD */
 
@@ -80,16 +78,15 @@ int main(int argc, char **argv)
 
 	Error error;
 	if (!ReadConfigFile(config_path, error)) {
-		g_printerr("%s\n", error.GetMessage());
-		return 1;
+		LogError(error);
+		return EXIT_FAILURE;
 	}
 
-	io_thread_init();
-	io_thread_start();
+	const ScopeIOThread io_thread;
 
 	if (!input_stream_global_init(error)) {
 		LogError(error);
-		return 2;
+		return EXIT_FAILURE;
 	}
 
 	playlist_list_global_init();
@@ -104,59 +101,59 @@ int main(int argc, char **argv)
 	if (playlist == NULL) {
 		/* open the stream and wait until it becomes ready */
 
-		is = InputStream::Open(uri, mutex, cond, error);
+		is = InputStream::OpenReady(uri, mutex, cond, error);
 		if (is == NULL) {
 			if (error.IsDefined())
 				LogError(error);
 			else
-				g_printerr("InputStream::Open() failed\n");
+				fprintf(stderr,
+					"InputStream::Open() failed\n");
 			return 2;
 		}
 
-		is->LockWaitReady();
-
 		/* open the playlist */
 
 		playlist = playlist_list_open_stream(*is, uri);
 		if (playlist == NULL) {
-			is->Close();
-			g_printerr("Failed to open playlist\n");
+			delete is;
+			fprintf(stderr, "Failed to open playlist\n");
 			return 2;
 		}
 	}
 
 	/* dump the playlist */
 
+	DetachedSong *song;
 	while ((song = playlist->NextSong()) != NULL) {
-		g_print("%s\n", song->uri);
+		printf("%s\n", song->GetURI());
 
-		if (song->end_ms > 0)
-			g_print("range: %u:%02u..%u:%02u\n",
-				song->start_ms / 60000,
-				(song->start_ms / 1000) % 60,
-				song->end_ms / 60000,
-				(song->end_ms / 1000) % 60);
-		else if (song->start_ms > 0)
-			g_print("range: %u:%02u..\n",
-				song->start_ms / 60000,
-				(song->start_ms / 1000) % 60);
+		const unsigned start_ms = song->GetStartTime().ToMS();
+		const unsigned end_ms = song->GetEndTime().ToMS();
 
-		if (song->tag != NULL)
-			tag_save(stdout, *song->tag);
+		if (end_ms > 0)
+			printf("range: %u:%02u..%u:%02u\n",
+			       start_ms / 60000,
+			       (start_ms / 1000) % 60,
+			       end_ms / 60000,
+			       (end_ms / 1000) % 60);
+		else if (start_ms > 0)
+			printf("range: %u:%02u..\n",
+			       start_ms / 60000,
+			       (start_ms / 1000) % 60);
 
-		song->Free();
+		tag_save(stdout, song->GetTag());
+
+		delete song;
 	}
 
 	/* deinitialize everything */
 
 	delete playlist;
-	if (is != NULL)
-		is->Close();
+	delete is;
 
 	decoder_plugin_deinit_all();
 	playlist_list_global_finish();
 	input_stream_global_finish();
-	io_thread_deinit();
 	config_global_finish();
 
 	return 0;
