@@ -28,11 +28,14 @@
 #include "util/Error.hxx"
 #include "Log.hxx"
 
+#ifdef HAVE_GLIB
 #include <glib.h>
+#endif
 
 #include <assert.h>
 #include <string.h>
 #include <unistd.h>
+#include <stdlib.h>
 
 const struct filter_plugin *
 filter_plugin_by_name(gcc_unused const char *name)
@@ -50,8 +53,10 @@ int main(int argc, gcc_unused char **argv)
 		return EXIT_FAILURE;
 	}
 
+#ifdef HAVE_GLIB
 #if !GLIB_CHECK_VERSION(2,32,0)
 	g_thread_init(NULL);
+#endif
 #endif
 
 	EventLoop event_loop;
