@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 The Music Player Daemon Project
+ * Copyright (C) 2003-2014 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,15 +24,17 @@
  */
 
 #include "config.h"
-#include "pcm/PcmVolume.hxx"
+#include "pcm/Volume.hxx"
 #include "AudioParser.hxx"
 #include "AudioFormat.hxx"
+#include "util/ConstBuffer.hxx"
 #include "util/Error.hxx"
 #include "stdbin.h"
+#include "Log.hxx"
 
-#include <glib.h>
-
+#include <stdio.h>
 #include <stddef.h>
+#include <stdlib.h>
 #include <unistd.h>
 
 int main(int argc, char **argv)
@@ -41,28 +43,29 @@ int main(int argc, char **argv)
 	ssize_t nbytes;
 
 	if (argc > 2) {
-		g_printerr("Usage: software_volume [FORMAT] <IN >OUT\n");
-		return 1;
+		fprintf(stderr, "Usage: software_volume [FORMAT] <IN >OUT\n");
+		return EXIT_FAILURE;
 	}
 
 	Error error;
 	AudioFormat audio_format(48000, SampleFormat::S16, 2);
 	if (argc > 1) {
 		if (!audio_format_parse(audio_format, argv[1], false, error)) {
-			g_printerr("Failed to parse audio format: %s\n",
-				   error.GetMessage());
-			return 1;
+			LogError(error, "Failed to parse audio format");
+			return EXIT_FAILURE;
 		}
 	}
 
+	PcmVolume pv;
+	if (!pv.Open(audio_format.format, error)) {
+		fprintf(stderr, "%s\n", error.GetMessage());
+		return EXIT_FAILURE;
+	}
+
 	while ((nbytes = read(0, buffer, sizeof(buffer))) > 0) {
-		if (!pcm_volume(buffer, nbytes,
-				audio_format.format,
-				PCM_VOLUME_1 / 2)) {
-			g_printerr("pcm_volume() has failed\n");
-			return 2;
-		}
-
-		gcc_unused ssize_t ignored = write(1, buffer, nbytes);
+		auto dest = pv.Apply({buffer, size_t(nbytes)});
+		gcc_unused ssize_t ignored = write(1, dest.data, dest.size);
 	}
+
+	pv.Close();
 }
