@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 The Music Player Daemon Project
+ * Copyright (C) 2003-2014 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,12 +19,12 @@
 
 #include "test_pcm_all.hxx"
 #include "test_pcm_util.hxx"
-#include "pcm/PcmDither.hxx"
+#include "pcm/PcmDither.cxx"
 
 void
 PcmDitherTest::TestDither24()
 {
-	constexpr unsigned N = 256;
+	constexpr unsigned N = 509;
 	const auto src = TestDataBuffer<int32_t, N>(RandomInt24());
 
 	int16_t dest[N];
@@ -40,7 +40,7 @@ PcmDitherTest::TestDither24()
 void
 PcmDitherTest::TestDither32()
 {
-	constexpr unsigned N = 256;
+	constexpr unsigned N = 509;
 	const auto src = TestDataBuffer<int32_t, N>();
 
 	int16_t dest[N];
