@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 The Music Player Daemon Project
+ * Copyright (C) 2003-2014 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,17 +29,14 @@
 void
 PcmFormatTest::TestFormat8to16()
 {
-	constexpr unsigned N = 256;
+	constexpr size_t N = 509;
 	const auto src = TestDataBuffer<int8_t, N>();
 
 	PcmBuffer buffer;
 
-	size_t d_size;
 	PcmDither dither;
-	auto d = pcm_convert_to_16(buffer, dither, SampleFormat::S8,
-				   src, sizeof(src), &d_size);
-	auto d_end = pcm_end_pointer(d, d_size);
-	CPPUNIT_ASSERT_EQUAL(N, unsigned(d_end - d));
+	auto d = pcm_convert_to_16(buffer, dither, SampleFormat::S8, src);
+	CPPUNIT_ASSERT_EQUAL(N, d.size);
 
 	for (size_t i = 0; i < N; ++i)
 		CPPUNIT_ASSERT_EQUAL(int(src[i]), d[i] >> 8);
@@ -48,16 +45,13 @@ PcmFormatTest::TestFormat8to16()
 void
 PcmFormatTest::TestFormat16to24()
 {
-	constexpr unsigned N = 256;
+	constexpr size_t N = 509;
 	const auto src = TestDataBuffer<int16_t, N>();
 
 	PcmBuffer buffer;
 
-	size_t d_size;
-	auto d = pcm_convert_to_24(buffer, SampleFormat::S16,
-				   src, sizeof(src), &d_size);
-	auto d_end = pcm_end_pointer(d, d_size);
-	CPPUNIT_ASSERT_EQUAL(N, unsigned(d_end - d));
+	auto d = pcm_convert_to_24(buffer, SampleFormat::S16, src);
+	CPPUNIT_ASSERT_EQUAL(N, d.size);
 
 	for (size_t i = 0; i < N; ++i)
 		CPPUNIT_ASSERT_EQUAL(int(src[i]), d[i] >> 8);
@@ -66,16 +60,13 @@ PcmFormatTest::TestFormat16to24()
 void
 PcmFormatTest::TestFormat16to32()
 {
-	constexpr unsigned N = 256;
+	constexpr size_t N = 509;
 	const auto src = TestDataBuffer<int16_t, N>();
 
 	PcmBuffer buffer;
 
-	size_t d_size;
-	auto d = pcm_convert_to_32(buffer, SampleFormat::S16,
-				   src, sizeof(src), &d_size);
-	auto d_end = pcm_end_pointer(d, d_size);
-	CPPUNIT_ASSERT_EQUAL(N, unsigned(d_end - d));
+	auto d = pcm_convert_to_32(buffer, SampleFormat::S16, src);
+	CPPUNIT_ASSERT_EQUAL(N, d.size);
 
 	for (size_t i = 0; i < N; ++i)
 		CPPUNIT_ASSERT_EQUAL(int(src[i]), d[i] >> 16);
@@ -84,31 +75,46 @@ PcmFormatTest::TestFormat16to32()
 void
 PcmFormatTest::TestFormatFloat()
 {
-	constexpr unsigned N = 256;
+	constexpr size_t N = 509;
 	const auto src = TestDataBuffer<int16_t, N>();
 
 	PcmBuffer buffer1, buffer2;
 
-	size_t f_size;
-	auto f = pcm_convert_to_float(buffer1, SampleFormat::S16,
-				      src, sizeof(src), &f_size);
-	auto f_end = pcm_end_pointer(f, f_size);
-	CPPUNIT_ASSERT_EQUAL(N, unsigned(f_end - f));
+	auto f = pcm_convert_to_float(buffer1, SampleFormat::S16, src);
+	CPPUNIT_ASSERT_EQUAL(N, f.size);
 
-	for (auto i = f; i != f_end; ++i) {
-		CPPUNIT_ASSERT(*i >= -1.);
-		CPPUNIT_ASSERT(*i <= 1.);
+	for (size_t i = 0; i != f.size; ++i) {
+		CPPUNIT_ASSERT(f[i] >= -1.);
+		CPPUNIT_ASSERT(f[i] <= 1.);
 	}
 
 	PcmDither dither;
 
-	size_t d_size;
 	auto d = pcm_convert_to_16(buffer2, dither,
 				   SampleFormat::FLOAT,
-				   f, f_size, &d_size);
-	auto d_end = pcm_end_pointer(d, d_size);
-	CPPUNIT_ASSERT_EQUAL(N, unsigned(d_end - d));
+				   f.ToVoid());
+	CPPUNIT_ASSERT_EQUAL(N, d.size);
 
 	for (size_t i = 0; i < N; ++i)
 		CPPUNIT_ASSERT_EQUAL(src[i], d[i]);
+
+	/* check if clamping works */
+	float *writable = const_cast<float *>(f.data);
+	*writable++ = 1.01;
+	*writable++ = 10;
+	*writable++ = -1.01;
+	*writable++ = -10;
+
+	d = pcm_convert_to_16(buffer2, dither,
+			      SampleFormat::FLOAT,
+			      f.ToVoid());
+	CPPUNIT_ASSERT_EQUAL(N, d.size);
+
+	CPPUNIT_ASSERT_EQUAL(32767, int(d[0]));
+	CPPUNIT_ASSERT_EQUAL(32767, int(d[1]));
+	CPPUNIT_ASSERT_EQUAL(-32768, int(d[2]));
+	CPPUNIT_ASSERT_EQUAL(-32768, int(d[3]));
+
+	for (size_t i = 4; i < N; ++i)
+		CPPUNIT_ASSERT_EQUAL(src[i], d[i]);
 }
